@@ -131,6 +131,7 @@ class CSVKitUtility(object):
         Extracts those from the command-line arguments those would should be passed through to the input CSV reader(s).
         """
         kwargs = {}
+
         if self.args.encoding:
             kwargs['encoding'] = self.args.encoding
 
@@ -187,8 +188,10 @@ class CSVKitUtility(object):
 def match_column_identifier(column_names, c):
     """
     Determine what column a single column id (name or index) matches in a series of column names.
+    Note that integer values are *always* treated as positional identifiers. If you happen to have
+    column names which are also integers, you must specify them using a positional index.
     """
-    if c in column_names:
+    if isinstance(c, basestring) and not c.isdigit() and c in column_names:
         return column_names.index(c)
     else:
         try:
@@ -234,4 +237,3 @@ def print_column_names(f, output, **reader_kwargs):
     for i, c in enumerate(column_names):
         output.write('%3i: %s\n' % (i + 1, c))
 
-    sys.exit()
