@@ -80,8 +80,8 @@ def pattern_as_function(obj):
     if hasattr(obj, 'match'):
         return regex_callable(obj)
 
-    # obj is string or pattern
-    return regex_callable(re.compile(obj))
+    # obj is string
+    return lambda x: obj in x
 
 class regex_callable(object):
     def __init__(self, pattern):
